#[temporary]Expand description
Mark code as temporary or intended to be replaced. This helps identify code that should not be considered permanent. This attribute does not modify the item it annotates.
#[temporary]Mark code as temporary or intended to be replaced. This helps identify code that should not be considered permanent. This attribute does not modify the item it annotates.